#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-72Rr9b6Vaw8CATODZpgl8Z
key:                  hls-test-utils-2.3.0.0-72Rr9b6Vaw8CATODZpgl8Z
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  985eed621c2c17c8c5dddf9770b82f78
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-72Rr9b6Vaw8CATODZpgl8Z
depends:
    aeson-2.2.2.0-5ic0qdnYZHH6zFYkxFCOtx
    async-2.2.6-AoIAnpP1AE52EgJKBLwe0w base-4.18.2.1
    blaze-markup-0.8.3.0-cyi0Fpqe62J2suaFuJVt7 bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-GWfmROYPtdX1tMV8eki8U8
    directory-1.3.8.5 extra-1.7.16-53b454gmz0kFA1gZEklCYN
    filepath-1.4.300.1 ghcide-2.3.0.0-DeYtsrKQlkOBQLbQvZtKdd
    hls-graph-2.3.0.0-L6iIZ7m7w1YJa2Z6meY774
    hls-plugin-api-2.3.0.0-Lpx2Nh226V079b3MemSa0j
    lens-5.3.4-7EFHuOJ8RipEfJSuyvyaT1
    lsp-2.2.0.0-8mf8q1mXbd2HMf20ri37xs
    lsp-test-0.16.0.0-E2ljf0gUEHI7lk7VVY1rt4
    lsp-types-2.0.2.0-7od6wfuIoHdC81PFEfihe5
    row-types-1.0.1.2-C0qv73e4TzQJfAFBPR4bwl
    tasty-1.5.2-7etf4ERGZjT5H3LzqJZmnC
    tasty-expected-failure-0.12.3-I7HFIrBOjSyKHYpOt4tbSY
    tasty-golden-2.3.6-BklptymHimjBLlbl24kaeo
    tasty-hunit-0.10.2-A3ySO0OReK35Id5kmUaml6
    tasty-rerun-1.1.20-CHV07WQ7PAr7iX6rfvyFgn
    temporary-1.3-HXy7P617zDdIZTm3EWvMYL text-2.0.2
    unordered-containers-0.2.20.1-1VPUCssH1vYLkUFtdr2cZd

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

